Struct fdir::file::FileInfo

source ·
pub struct FileInfo { /* private fields */ }

Implementations

source

impl FileInfo

source

pub fn open(path: impl AsRef<Path>) -> Result<FileInfo>

source

pub fn create(path: impl AsRef<Path>) -> Result<FileInfo>

source

pub fn file_stem(&self) -> Option<&OsStr>

source

pub fn extension(&self) -> Option<&OsStr>

source

pub fn set_extension(&mut self, ext: impl AsRef<OsStr>) -> Result<()>

source

pub fn close(&mut self)

Close the file read-write stream

source

pub fn start_reading(&mut self) -> Result<()>

source

pub fn read(&mut self, len: usize) -> _Result<Vec<u8>>

Reads bytes of the specified length

Examples
use fdir::FileInfo;
use fdir::buffer::Error;

let mut f = FileInfo::create("foo.txt").unwrap();
f.start_writing().unwrap();
f.write("Hello world!").unwrap();

f.start_reading().unwrap();
let hello = f.read(5).unwrap();
assert_eq!(hello.as_slice(), b"Hello");

let world = f.read(6).unwrap();
assert_eq!(world.as_slice(), b" world");

let s = f.read(5).unwrap();
assert_eq!(s.as_slice(), b"!");

let eof = f.read(5);
assert!(eof.is_err());
source

pub fn read_to_end<T: ReadBuf>(&mut self) -> _Result<T>

Read all the remaining bytes and convert it to any type that implements ReadBuf

Examples
use fdir::FileInfo;
use fdir::buffer::Error;

let mut f = FileInfo::create("foo.txt").unwrap();
f.start_writing().unwrap();
f.write("1234567").unwrap();

f.start_reading().unwrap();
f.read(4).unwrap();

let n: i32 = f.read_to_end().unwrap();
assert_eq!(n, 567)
source

pub fn read_line<T: ReadBuf>(&mut self) -> _Result<T>

Read one line and convert it to any type that implements ReadBuf

Examples
use fdir::FileInfo;
use fdir::buffer::Error;

let mut f = FileInfo::create("foo.txt").unwrap();
f.start_writing().unwrap();
f.writeln("Hello").unwrap();
f.writeln("World").unwrap();

f.start_reading().unwrap();
let hello: String = f.read_line().unwrap();
let world: String = f.read_line().unwrap();
assert_eq!(hello.as_str(), "Hello");
assert_eq!(world.as_str(), "World");
source

pub fn read_until<T: ReadBuf>(&mut self, byte: u8) -> _Result<T>

Read all bytes into buf until the delimiter byte or EOF is reached and convert it to any type that implements ReadBuf

Examples
use fdir::FileInfo;
use fdir::buffer::Error;

let mut f = FileInfo::create("foo.txt").unwrap();
f.start_writing().unwrap();
f.write("Hello World !").unwrap();

f.start_reading().unwrap();
let hello: String = f.read_until(b' ').unwrap();
let world: String = f.read_until(b' ').unwrap();
let s: String = f.read_until(b' ').unwrap();
assert_eq!(hello.as_str(), "Hello");
assert_eq!(world.as_str(), "World");
assert_eq!(s.as_str(), "!")
source

pub fn truncate(&mut self) -> Result<()>

It will truncate the file to 0 length

source

pub fn start_writing(&mut self) -> Result<()>

source

pub fn write<T: AsRef<[u8]>>(&mut self, buf: T) -> _Result<()>

source

pub fn writeln<T: AsRef<[u8]>>(&mut self, buf: T) -> _Result<()>

source

pub fn write_end_with<T: AsRef<[u8]>>(&mut self, buf: T, end: u8) -> _Result<()>